@@ -12,7 +12,8 @@ sub new{
     return $self;
 }
 sub render{
-    my ($self, $options)=@_;
+    my ($self, $options, $view)=@_;
+    if ($view) { $self->{view}=$view; }  
     my $request=$self->request;
     my $result='';
     my $disabled='';
